import React, { useState, useCallback, useEffect, } from 'react';
import ReactDOM from 'react-dom';
import { csv, scaleLinear, scalePoint, max, format, extent, reverse } from 'd3';
import { useData } from './useData';
import { AxisBottom } from './AxisBottom';
import { AxisLeft1 } from './AxisLeft1';
import { AxisLeft2 } from './AxisLeft2';
import { Marks1 } from './Marks1';
import { Marks2 } from './Marks2';

const width = 960;
const height = 500;
const plotSize = 0.5;
const margin = { top: 10, right: 50, bottom: 0, left: 90 };
const xAxisLabelOffset = -175;
const yAxisLabelOffset = 60;

const App = () => {
  const data = useData();
  const [hoveredValue,setHoveredValue] = useState(null);
  console.log(hoveredValue);
  
  if (!data) {
    return <pre>Loading...</pre>;
  }

  const innerHeight = (height - margin.top - margin.bottom)/3;
  const innerWidth = width - margin.left - margin.right;
 
  const xValue = d => d.Tier
  const xAxisLabel = 'Level of Engagement';
  
  const y1Value = d => d.Price;
  const y1AxisLabel = 'Price';
  
  const y2Value = d => d.Earnings;
  const y2AxisLabel = 'Earnings';
  
  const orgName = d => d['Org Name']
  
  const filteredData=data.filter(d=>hoveredValue=== d['Org Name']);
  
  const circleRadius=5;
  
  const siFormat = format('d');
  const xAxisTickFormat = tickValue => siFormat(tickValue);
  
  const xScale = scaleLinear()
    .domain(extent(data,xValue))
    .range([0, innerWidth]);

  const y1Scale = scaleLinear()
    .domain(extent(data,y1Value))
    .range([innerHeight, 0]);
  
  const y2Scale = scaleLinear()
    .domain(extent(data,y2Value))
    .range([innerHeight, 0]);

  return (
    <>
        <svg width={width} height={height}>
//Price vs. Tier
        <g transform={`translate(100,30)`}>
          <AxisBottom
            xScale={xScale}
            innerHeight={innerHeight}
            tickFormat={xAxisTickFormat}
            tickOffset={5}
          />
          <text
            className="axis-label"
            textAnchor="middle"
            transform={`translate(${-yAxisLabelOffset},${innerHeight /
              2}) rotate(-90)`}
          >
            {y1AxisLabel}
          </text>
          <AxisLeft1 y1Scale={y1Scale} innerWidth={innerWidth} tickOffset={5} />
          <g opacity={hoveredValue ? 0.2 : 1}>
          <Marks1
            data={data}
            xScale={xScale}
            y1Scale={y1Scale}
            xValue={xValue}
            y1Value={y1Value}
            tooltipFormat={xAxisTickFormat}
            circleRadius={5}
            onHover={setHoveredValue}
          />
          </g>
          <Marks1
            data={filteredData}
            xScale={xScale}
            y1Scale={y1Scale}
            xValue={xValue}
            y1Value={y1Value}
            tooltipFormat={xAxisTickFormat}
            circleRadius={5}
            onHover={setHoveredValue}
          />
        </g>
//Outcome vs. Tier
        <g transform={`translate(100,${plotSize * height})`}>
          <AxisBottom
            xScale={xScale}
            innerHeight={innerHeight}
            tickFormat={xAxisTickFormat}
            tickOffset={5}
          />
          <text
            className="axis-label"
            textAnchor="middle"
            transform={`translate(${-yAxisLabelOffset},${innerHeight /
              2}) rotate(-90)`}
          >
            {y2AxisLabel}
          </text>
          <AxisLeft2 y2Scale={y2Scale} innerWidth={innerWidth} tickOffset={5} />
          <text
            className="axis-label"
            x={innerWidth / 2}
            y={innerHeight + xAxisLabelOffset}
            textAnchor="middle"
          >
            {xAxisLabel}
          </text>
					<g opacity={hoveredValue ? 0.2 : 1}>
          <Marks2
            data={data}
            xScale={xScale}
            y2Scale={y2Scale}
            xValue={xValue}
            y2Value={y2Value}
            tooltipFormat={xAxisTickFormat}
            circleRadius={5}
            onHover={setHoveredValue}
          />
          </g>
          <Marks2
            data={filteredData}
            xScale={xScale}
            y2Scale={y2Scale}
            xValue={xValue}
            y2Value={y2Value}
            tooltipFormat={xAxisTickFormat}
            circleRadius={5}
            onHover={setHoveredValue}
          />
        </g>          
      </svg>
    </>
  );
};
const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
